<?php

namespace Drupal\language_block_hide_language\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class HideLanguageSettingsForm extends ConfigFormBase {

  /**
   * @inheritDoc
   */
  protected function getEditableConfigNames() {
    return ['language_block_hide_language.settings'];
  }

  /**
   * @inheritDoc
   */
  public function getFormId() {
    return 'language_block_hide_language_settings';
  }

  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('language_block_hide_language.settings');
    // Get installed languages.
    $languages = \Drupal::languageManager()->getLanguages();
    $language_options = [];
    foreach ($languages as $language) {
      $language_options[$language->getId()] = $language->getName();
    }
    $form['language'] = [
      '#type' => 'select',
      '#title' => $this->t('Select the language to hide'),
      '#description' => $this->t('These language will be hidden.'),
      '#options' => $language_options,
      '#default_value' => $config->get('language'),
      '#multiple' => TRUE,
    ];
    return parent::buildForm($form, $form_state);
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    \Drupal::service('config.factory')
      ->getEditable('language_block_hide_language.settings')
      ->set('language', $form_state->getValue('language'))
      ->save();
    parent::submitForm($form, $form_state);
  }
}
