<?php

namespace Drupal\language_block_hide_language;

use Drupal\Core\Security\TrustedCallbackInterface;

/**
 * Add Pre-render trusted callback for language_block_hide_language.
 */
class LanguageBlockHideLanguageRender implements TrustedCallbackInterface {

  /**
   * {@inheritdoc}
   */
  public static function trustedCallbacks() {
    return ['preRender'];
  }

  /**
   * Pre-render callback for layout builder.
   */
  public static function preRender($elements) {
    $hide_language = \Drupal::config('language_block_hide_language.settings')->get('language');

    if (empty($hide_language)) {
      return $elements;
    }

    // Hide the language using the language code.
    foreach ($elements['content']['#links'] as $key => $link) {
      if (in_array($key, $hide_language)) {
        unset($elements['content']['#links'][$key]);
      }
    }

    return $elements;
  }

}
